@@ -11,7 +11,7 @@ var indexSectionsWithContent =
   8: "abcdefghijklmnopqrstuvwxyz",
   9: ":fgimotw",
   10: "ct",
-  11: "adflnpt"
+  11: "abcdefilnopstu"
 };
 
 var indexSectionNames =
